var servicecom_1_1sun_1_1star_1_1sdb_1_1DataColumn =
[
    [ "com::sun::star::sdb::ResultColumn", "servicecom_1_1sun_1_1star_1_1sdb_1_1DataColumn.html#a59e34e0e5f69d2e3a3d2f6ba4ff15a16", null ],
    [ "XColumn", "servicecom_1_1sun_1_1star_1_1sdb_1_1DataColumn.html#a05afc4799023d022fb5a42266e246e2d", null ],
    [ "XColumnUpdate", "servicecom_1_1sun_1_1star_1_1sdb_1_1DataColumn.html#a8db34407a05409dfc3d982aaf2540eee", null ],
    [ "OriginalValue", "servicecom_1_1sun_1_1star_1_1sdb_1_1DataColumn.html#abd43549f6126b10faf6b0ec2a8b5b881", null ],
    [ "Value", "servicecom_1_1sun_1_1star_1_1sdb_1_1DataColumn.html#a5df18026de0211465d6189503ddd253a", null ]
];